/* File: drvMM4000.h 		   	*/
/* Version: 1.0		   	*/
/* Date Last Modified: 10-16-97	*/


/* Device Driver Support definitions for motor */
/*
 *      Original Author: Mark Rivers
 *      Current Author: Mark Rivers
 *      Date: 10/16/97
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the Regents of the University of California,
 *      and the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contracts:
 *      (W-7405-ENG-36) at the Los Alamos National Laboratory,
 *      and (W-31-109-ENG-38) at Argonne National Laboratory.
 *
 *      Initial development by:
 *	      The Controls and Automation Group (AT-8)
 *	      Ground Test Accelerator
 *	      Accelerator Technology Division
 *	      Los Alamos National Laboratory
 *
 *      Co-developed with
 *	      The Controls and Computing Group
 *	      Accelerator Systems Division
 *	      Advanced Photon Source
 *	      Argonne National Laboratory
 *
 * Modification Log:
 * -----------------
 * .01  01-18-93	mlr     initialized from drvOms58
 */

/*
 * valid command types for the driver, the order is importance, 0 is of
 * lowest importance.  Device support will choose the greatest one to use as
 * the driver transaction type.
 */

#define UNDEFINED (unsigned char)0	/* garbage type */
#define IMMEDIATE (unsigned char)1	/* an execute immediate, no reply */
#define MOVE_TERM (unsigned char)2	/* terminate a previous active 
                                           motion */
#define MOTION    (unsigned char)3	/* will produce motion updates */
#define VELOCITY  (unsigned char)4	/* make motion updates till
					 * MOVE_TERM */
#define INFO      (unsigned char)5	/* get curr motor/encoder pos and stat */
#define QUERY     (unsigned char)6	/* specialty type, not needed */

struct MM4000_support
{
    int (*init) ();
    int (*send) ();
    int (*free) ();
    int (*get_card_info) ();
    int (*get_axis_info) ();
};

/* message queue management - device and driver support only */
struct mess_node
{
    CALLBACK callback;
    int signal;
    int card;
    unsigned char type;
    char message[MESS_SIZE];
    double position;
    double encoder_position;
    double velocity;
    unsigned long status;
    struct dbCommon *precord;
    struct mess_node *next;
};
typedef struct mess_node MOTOR_CALL;
typedef struct mess_node MOTOR_RETURN;

typedef struct mess_card_query
{
    char *card_name;   
    int total_axis;
} MOTOR_CARD_QUERY;

typedef struct mess_axis_query
{
    double position;
    double encoder_position;
    double drive_resolution;
    double high_limit;
    double low_limit;
    unsigned long status;
} MOTOR_AXIS_QUERY;


/*
 * MM4000 default profile 
 */

#define MM4000_NUM_CARDS           4
#define MM4000_NUM_CHANNELS        8
